@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+"""
+    celery.backends.amqp
+    ~~~~~~~~~~~~~~~~~~~~
+
+    The AMQP result backend.
+
+    This backend publishes results as messages.
+
+"""
 from __future__ import absolute_import
 from __future__ import with_statement
 
@@ -6,16 +15,17 @@ import socket
 import threading
 import time
 
-from itertools import count
-
 from kombu.entity import Exchange, Queue
 from kombu.messaging import Consumer, Producer
 
-from .. import states
-from ..exceptions import TimeoutError
+from celery import states
+from celery.exceptions import TimeoutError
+from celery.utils.log import get_logger
 
 from .base import BaseDictBackend
 
+logger = get_logger(__name__)
+
 
 class BacklogLimitExceeded(Exception):
     """Too much state history to fast-forward."""
@@ -24,8 +34,8 @@ class BacklogLimitExceeded(Exception):
 def repair_uuid(s):
     # Historically the dashes in UUIDS are removed from AMQ entity names,
     # but there is no known reason to.  Hopefully we'll be able to fix
-    # this in v3.0.
-    return "%s-%s-%s-%s-%s" % (s[:8], s[8:12], s[12:16], s[16:20], s[20:])
+    # this in v4.0.
+    return '%s-%s-%s-%s-%s' % (s[:8], s[8:12], s[12:16], s[16:20], s[20:])
 
 
 class AMQPBackend(BaseDictBackend):
@@ -39,6 +49,13 @@ class AMQPBackend(BaseDictBackend):
 
     supports_native_join = True
 
+    retry_policy = {
+            'max_retries': 20,
+            'interval_start': 0,
+            'interval_step': 1,
+            'interval_max': 1,
+    }
+
     def __init__(self, connection=None, exchange=None, exchange_type=None,
             persistent=None, serializer=None, auto_delete=True,
             **kwargs):
@@ -48,7 +65,7 @@ class AMQPBackend(BaseDictBackend):
         self.queue_arguments = {}
         self.persistent = (conf.CELERY_RESULT_PERSISTENT if persistent is None
                                                          else persistent)
-        delivery_mode = persistent and "persistent" or "transient"
+        delivery_mode = persistent and 'persistent' or 'transient'
         exchange = exchange or conf.CELERY_RESULT_EXCHANGE
         exchange_type = exchange_type or conf.CELERY_RESULT_EXCHANGE_TYPE
         self.exchange = self.Exchange(name=exchange,
@@ -60,22 +77,22 @@ class AMQPBackend(BaseDictBackend):
         self.auto_delete = auto_delete
 
         # AMQP_TASK_RESULT_EXPIRES setting is deprecated and will be
-        # removed in version 3.0.
+        # removed in version 4.0.
         dexpires = conf.CELERY_AMQP_TASK_RESULT_EXPIRES
 
         self.expires = None
-        if "expires" in kwargs:
-            if kwargs["expires"] is not None:
-                self.expires = self.prepare_expires(kwargs["expires"])
+        if 'expires' in kwargs:
+            if kwargs['expires'] is not None:
+                self.expires = self.prepare_expires(kwargs['expires'])
         else:
             self.expires = self.prepare_expires(dexpires)
 
         if self.expires:
-            self.queue_arguments["x-expires"] = int(self.expires * 1000)
+            self.queue_arguments['x-expires'] = int(self.expires * 1000)
         self.mutex = threading.Lock()
 
     def _create_binding(self, task_id):
-        name = task_id.replace("-", "")
+        name = task_id.replace('-', '')
         return self.Queue(name=name,
                           exchange=self.exchange,
                           routing_key=name,
@@ -83,94 +100,79 @@ class AMQPBackend(BaseDictBackend):
                           auto_delete=self.auto_delete,
                           queue_arguments=self.queue_arguments)
 
-    def _create_producer(self, task_id, connection):
-        self._create_binding(task_id)(connection.default_channel).declare()
-        return self.Producer(connection, exchange=self.exchange,
-                             routing_key=task_id.replace("-", ""),
-                             serializer=self.serializer)
-
-    def _create_consumer(self, bindings, channel):
-        return self.Consumer(channel, bindings, no_ack=True)
-
-    def _publish_result(self, connection, task_id, meta):
-        # cache single channel
-        self._create_producer(task_id, connection).publish(meta)
-
     def revive(self, channel):
         pass
 
-    def _store_result(self, task_id, result, status, traceback=None,
-            max_retries=20, interval_start=0, interval_step=1,
-            interval_max=1):
+    def _store_result(self, task_id, result, status, traceback=None):
         """Send task return value and status."""
         with self.mutex:
-            with self.app.pool.acquire(block=True) as conn:
-
-                def errback(error, delay):
-                    print("Couldn't send result for %r: %r. Retry in %rs." % (
-                            task_id, error, delay))
-
-                send = conn.ensure(self, self._publish_result,
-                            max_retries=max_retries,
-                            errback=errback,
-                            interval_start=interval_start,
-                            interval_step=interval_step,
-                            interval_max=interval_max)
-                send(conn, task_id, {"task_id": task_id, "status": status,
-                                "result": self.encode_result(result, status),
-                                "traceback": traceback})
+            with self.app.amqp.producer_pool.acquire(block=True) as pub:
+                pub.publish({'task_id': task_id, 'status': status,
+                             'result': self.encode_result(result, status),
+                             'traceback': traceback,
+                             'children': self.current_task_children()},
+                            exchange=self.exchange,
+                            routing_key=task_id.replace('-', ''),
+                            serializer=self.serializer,
+                            retry=True, retry_policy=self.retry_policy,
+                            declare=[self._create_binding(task_id)])
         return result
 
-    def get_task_meta(self, task_id, cache=True):
-        return self.poll(task_id)
-
     def wait_for(self, task_id, timeout=None, cache=True, propagate=True,
             **kwargs):
         cached_meta = self._cache.get(task_id)
         if cache and cached_meta and \
-                cached_meta["status"] in states.READY_STATES:
+                cached_meta['status'] in states.READY_STATES:
             meta = cached_meta
         else:
             try:
                 meta = self.consume(task_id, timeout=timeout)
             except socket.timeout:
-                raise TimeoutError("The operation timed out.")
+                raise TimeoutError('The operation timed out.')
 
-        state = meta["status"]
+        state = meta['status']
         if state == states.SUCCESS:
-            return meta["result"]
+            return meta['result']
         elif state in states.PROPAGATE_STATES:
             if propagate:
-                raise self.exception_to_python(meta["result"])
-            return meta["result"]
+                raise self.exception_to_python(meta['result'])
+            return meta['result']
         else:
             return self.wait_for(task_id, timeout, cache)
 
-    def poll(self, task_id, backlog_limit=100):
+    def get_task_meta(self, task_id, backlog_limit=1000):
+        # Polling and using basic_get
         with self.app.pool.acquire_channel(block=True) as (_, channel):
             binding = self._create_binding(task_id)(channel)
             binding.declare()
             latest, acc = None, None
-            for i in count():  # fast-forward
+            for i in xrange(backlog_limit):
                 latest, acc = acc, binding.get(no_ack=True)
-                if not acc:
+                if not acc:  # no more messages
                     break
-                if i > backlog_limit:
-                    raise self.BacklogLimitExceeded(task_id)
+            else:
+                raise self.BacklogLimitExceeded(task_id)
+
             if latest:
+                # new state to report
                 payload = self._cache[task_id] = latest.payload
                 return payload
-            elif task_id in self._cache:  # use previously received state.
-                return self._cache[task_id]
-            return {"status": states.PENDING, "result": None}
+            else:
+                # no new state, use previous
+                try:
+                    return self._cache[task_id]
+                except KeyError:
+                    # result probably pending.
+                    return {'status': states.PENDING, 'result': None}
+    poll = get_task_meta  # XXX compat
 
     def drain_events(self, connection, consumer, timeout=None, now=time.time):
         wait = connection.drain_events
         results = {}
 
         def callback(meta, message):
-            if meta["status"] in states.READY_STATES:
-                uuid = repair_uuid(message.delivery_info["routing_key"])
+            if meta['status'] in states.READY_STATES:
+                uuid = repair_uuid(message.delivery_info['routing_key'])
                 results[uuid] = meta
 
         consumer.callbacks[:] = [callback]
@@ -189,7 +191,7 @@ class AMQPBackend(BaseDictBackend):
     def consume(self, task_id, timeout=None):
         with self.app.pool.acquire_channel(block=True) as (conn, channel):
             binding = self._create_binding(task_id)
-            with self._create_consumer(binding, channel) as consumer:
+            with self.Consumer(channel, binding, no_ack=True) as consumer:
                 return self.drain_events(conn, consumer, timeout).values()[0]
 
     def get_many(self, task_ids, timeout=None, **kwargs):
@@ -202,13 +204,13 @@ class AMQPBackend(BaseDictBackend):
                 except KeyError:
                     pass
                 else:
-                    if cached["status"] in states.READY_STATES:
+                    if cached['status'] in states.READY_STATES:
                         yield task_id, cached
                         cached_ids.add(task_id)
-
             ids ^= cached_ids
+
             bindings = [self._create_binding(task_id) for task_id in task_ids]
-            with self._create_consumer(bindings, channel) as consumer:
+            with self.Consumer(channel, bindings, no_ack=True) as consumer:
                 while ids:
                     r = self.drain_events(conn, consumer, timeout)
                     ids ^= set(r)
@@ -217,32 +219,31 @@ class AMQPBackend(BaseDictBackend):
 
     def reload_task_result(self, task_id):
         raise NotImplementedError(
-                "reload_task_result is not supported by this backend.")
+                'reload_task_result is not supported by this backend.')
 
-    def reload_taskset_result(self, task_id):
-        """Reload taskset result, even if it has been previously fetched."""
+    def reload_group_result(self, task_id):
+        """Reload group result, even if it has been previously fetched."""
         raise NotImplementedError(
-                "reload_taskset_result is not supported by this backend.")
+                'reload_group_result is not supported by this backend.')
 
-    def save_taskset(self, taskset_id, result):
+    def save_group(self, group_id, result):
         raise NotImplementedError(
-                "save_taskset is not supported by this backend.")
+                'save_group is not supported by this backend.')
 
-    def restore_taskset(self, taskset_id, cache=True):
+    def restore_group(self, group_id, cache=True):
         raise NotImplementedError(
-                "restore_taskset is not supported by this backend.")
+                'restore_group is not supported by this backend.')
 
-    def delete_taskset(self, taskset_id):
+    def delete_group(self, group_id):
         raise NotImplementedError(
-                "delete_taskset is not supported by this backend.")
+                'delete_group is not supported by this backend.')
 
     def __reduce__(self, args=(), kwargs={}):
-        kwargs.update(
-            dict(connection=self._connection,
-                 exchange=self.exchange.name,
-                 exchange_type=self.exchange.type,
-                 persistent=self.persistent,
-                 serializer=self.serializer,
-                 auto_delete=self.auto_delete,
-                 expires=self.expires))
+        kwargs.update(connection=self._connection,
+                      exchange=self.exchange.name,
+                      exchange_type=self.exchange.type,
+                      persistent=self.persistent,
+                      serializer=self.serializer,
+                      auto_delete=self.auto_delete,
+                      expires=self.expires)
         return super(AMQPBackend, self).__reduce__(args, kwargs)
