@@ -29,7 +29,7 @@ from celery import concurrency as _concurrency
 from celery import platforms
 from celery.app import app_or_default, set_default_app
 from celery.app.abstract import configurated, from_config
-from celery.exceptions import SystemTerminate
+from celery.exceptions import SystemTerminate, TaskRevokedError
 from celery.task import trace
 from celery.utils.functional import noop
 from celery.utils.imports import qualname, reload_from_cwd
@@ -320,9 +320,7 @@ class WorkController(configurated):
         self._finalize = Finalize(self, self.stop, exitpriority=1)
         self.pidfile = pidfile
         self.pidlock = None
-        self.use_eventloop = (detect_environment() == 'default' and
-                              self.app.connection().is_evented and
-                              not self.app.IS_WINDOWS)
+        self.use_eventloop = self.should_use_eventloop()
 
         # Update celery_include to have all known task modules, so that we
         # ensure all task modules are imported in case an execv happens.
@@ -369,6 +367,9 @@ class WorkController(configurated):
         """Process task by sending it to the pool of workers."""
         try:
             req.execute_using_pool(self.pool)
+        except TaskRevokedError:
+            if self.semaphore:  # (Issue #877)
+                self.semaphore.release()
         except Exception, exc:
             logger.critical('Internal error: %r\n%s',
                             exc, traceback.format_exc(), exc_info=True)
@@ -385,6 +386,10 @@ class WorkController(configurated):
         except AttributeError:
             pass
 
+    def should_use_eventloop(self):
+        return (detect_environment() == 'default' and
+                self.app.connection().is_evented and not self.app.IS_WINDOWS)
+
     def stop(self, in_sighandler=False):
         """Graceful shutdown of the worker server."""
         self.signal_consumer_close()
