@@ -6,9 +6,6 @@
     This is the internal thread that sends heartbeat events
     at regular intervals.
 
-    :copyright: (c) 2009 - 2012 by Ask Solem.
-    :license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -28,7 +25,7 @@ class Heart(object):
     def __init__(self, timer, eventer, interval=None):
         self.timer = timer
         self.eventer = eventer
-        self.interval = interval or 30
+        self.interval = float(interval or 5.0)
         self.tref = None
 
         # Make event dispatcher start/stop us when it's
@@ -37,17 +34,17 @@ class Heart(object):
         self.eventer.on_disabled.add(self.stop)
 
     def _send(self, event):
-        return self.eventer.send(event, **SOFTWARE_INFO)
+        return self.eventer.send(event, freq=self.interval, **SOFTWARE_INFO)
 
     def start(self):
         if self.eventer.enabled:
-            self._send("worker-online")
+            self._send('worker-online')
             self.tref = self.timer.apply_interval(self.interval * 1000.0,
-                    self._send, ("worker-heartbeat", ))
+                    self._send, ('worker-heartbeat', ))
 
     def stop(self):
         if self.tref is not None:
             self.timer.cancel(self.tref)
             self.tref = None
         if self.eventer.enabled:
-            self._send("worker-offline")
+            self._send('worker-offline')
