@@ -2,7 +2,7 @@
 
 Usage:
 
-   (window1)$ python myapp.py -l info
+   (window1)$ python myapp.py worker -l info
 
    (window2)$ python
    >>> from myapp import add
@@ -12,19 +12,17 @@ Usage:
 
 You can also specify the app to use with celeryd::
 
-    $ celeryd -l info --app=myapp.celery
+    $ celery worker -l info --app=myapp
 
 """
 from celery import Celery
 
-
-celery = Celery("myapp")
-celery.conf.update(BROKER_URL="amqp://guest:guest@localhost:5672//")
+celery = Celery('myapp', broker='amqp://guest@localhost//')
 
 
-@celery.task
+@celery.task()
 def add(x, y):
     return x + y
 
-if __name__ == "__main__":
-    celery.worker_main()
+if __name__ == '__main__':
+    celery.start()
